import qrcode
from io import BytesIO
import random

def generate_qr(id: str) -> BytesIO:
    id = "csj65ljmvq8nf5ct90b0"
    # device_id = "7431993851172124419"
    device_id = None
    url = f"https://kimi.moonshot.cn/wechat/mp/auth?id={id}&device_id={device_id}"    
    # 生成二维码
    img = qrcode.make(url)
    # 将二维码保存到BytesIO对象中
    buf = BytesIO()
    img.save(buf)
    buf.seek(0)
    print(type(buf))
    return buf

def test2():
    id = "7431993851172124419"
    print(len(id))

def gen_random_num(num_len: int):
    random_number = random.randint(10**(num_len-1), 10**num_len - 1)
    return random_number

if __name__ == "__main__":
    pass
    


import requests
import json
import time
from kimi_craw.configs import header_config
from kimi_craw.utils import utils
# import ssl
# ssl._create_default_https_context = ssl._create_unverified_context

# 获取游客模式的token
def get_visitor_token() -> str:
    
    # todo
    # 限制太大，没必要写。
    # 还是要写一下，因为后续要做登录需要使用到该接口生成的临时token
    '''
    =======该接口返回=========
    {
        access_token: "ey...",
        refresh_token: "ey...",
    }
    =========================
    只是临时token,可用于游客模式
    '''
    url = "https://kimi.moonshot.cn/api/device/register"
    # headers['Authorization'] = "Bearer "
    headers=header_config.base_headers
    # headers['X-MSH-Session-ID'] = str(utils.gen_random_num(19))
    print("======================")
    print(headers)
    res = requests.post(url=url, headers=headers, data=json.dumps({}))
    data = res.json()
    # print(data)
    return data['access_token'] # 只返回access_token就可以

# 生成登录id
# url = https://kimi.moonshot.cn/api/user/wx/register_login POST
# 返回: {"id":"csjdmf0967u4nqsk45vg"}
def get_login_id() -> dict:
    url = "https://kimi.moonshot.cn/api/user/wx/register_login"
    res = requests.post(url=url, headers=header_config.base_headers)
    data = res.json()
    return data['id']

# 获取登录二维码
def get_qrcode(login_id):
    # 1. 获取登录id 
    # login_id = get_login_id()

    # 2. 获取登录二维码
    qr_img = utils.generate_qr(login_id)

    # 3. 返回
    return qr_img

    
# 检查用户是否登录，结合轮询使用
def check_login(login_id: str, tmp_access_token: str) -> dict:
    url = f"https://kimi.moonshot.cn/api/user/wx/register_login/{login_id}"
    headers = header_config.base_headers
    # headers['Authorization'] = "Bearer " + tmp_access_token
    
    res = requests.get(url=url, headers=header_config.base_headers)
    data = res.json()
    return data


# if __name__ == '__main__':
#     get_login_id()
    




base_headers = {
  "Host": "kimi.moonshot.cn",
  "Connection": "keep-alive",
  "Pragma": "no-cache",
  "Cache-Control": "no-cache",
  "X-MSH-Session-ID": "None",
  "sec-ch-ua-platform": "Windows",
  "x-msh-platform": "web",
  "X-MSH-Device-ID": "None",
  "R-Timezone": "None",
  "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36 Edg/130.0.0.0",
  "Content-Type": "application/json",
}


import setuptools
with open("README.md",  "r" , encoding='gbk' , errors='ignore') as fh:
    long_description = fh.read()
setuptools.setup(
    name="kimi_craw",  # 模块名称
    version="1.0.4",  # 当前版本
    author="windheart",  # 作者
    author_email="2916311184@qq.com",  # 作者邮箱
    description="kimi_craw",  # 模块简介
    long_description=long_description,  # 模块详细介绍
    long_description_content_type="text/markdown",  # 模块详细介绍格式
    # url="https://github.com/wupeiqi/fucker",  # 模块github地址
    packages=setuptools.find_packages(),  # 自动找到项目中导入的模块
    # 模块相关的元数据
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # 依赖模块
    install_requires=[
        # 'pillow',
        "requests",
        "qrcode"
    ],
    python_requires='>=3',
)

# 打包上传命令
# 要先删掉dist和build文件夹
# python setup.py sdist bdist_wheel
# twine upload dist/*